@@ -1,16 +1,16 @@
 ### R code from vignette source 'using_tinytest.Rnw'
-### Encoding: UTF-8
 
 ###################################################
-### code chunk number 1: using_tinytest.Rnw:79-82
+### code chunk number 1: using_tinytest.Rnw:79-83
 ###################################################
 options(prompt="R>  ",
         continue = "    ",
-        width=75)
+        width=75,
+        tt.pr.color=FALSE)
 
 
 ###################################################
-### code chunk number 2: using_tinytest.Rnw:107-113
+### code chunk number 2: using_tinytest.Rnw:108-114
 ###################################################
 lbs2kg <- function(x){
   if ( x < 0 ){
@@ -21,7 +21,7 @@ lbs2kg <- function(x){
 
 
 ###################################################
-### code chunk number 3: using_tinytest.Rnw:116-119
+### code chunk number 3: using_tinytest.Rnw:117-120
 ###################################################
 library(tinytest)
 expect_equal(lbs2kg(1), 1/2.2046)
@@ -29,26 +29,26 @@ expect_error(lbs2kg(-3))
 
 
 ###################################################
-### code chunk number 4: using_tinytest.Rnw:125-126
+### code chunk number 4: using_tinytest.Rnw:126-127
 ###################################################
 isTRUE( expect_true(2 == 1 + 1) )
 
 
 ###################################################
-### code chunk number 5: using_tinytest.Rnw:150-152
+### code chunk number 5: using_tinytest.Rnw:151-153
 ###################################################
 expect_error(lbs2kg(-3), pattern="nonnegative")
 expect_error(lbs2kg(-3), pattern="foo")
 
 
 ###################################################
-### code chunk number 6: using_tinytest.Rnw:166-167
+### code chunk number 6: using_tinytest.Rnw:167-168
 ###################################################
 expect_false( 1 + 1 == 2, info="My personal message to the tester" )
 
 
 ###################################################
-### code chunk number 7: using_tinytest.Rnw:198-199
+### code chunk number 7: using_tinytest.Rnw:199-200
 ###################################################
 print(expect_equal(1+1, 3), type="short")
 
@@ -60,45 +60,45 @@ run_test_file("test_addOne.R", verbose=0)
 
 
 ###################################################
-### code chunk number 9: using_tinytest.Rnw:245-247
+### code chunk number 9: using_tinytest.Rnw:246-248
 ###################################################
 test_results <- run_test_file("test_addOne.R", verbose=0)
 print(test_results, passes=TRUE)
 
 
 ###################################################
-### code chunk number 10: using_tinytest.Rnw:250-251 (eval = FALSE)
+### code chunk number 10: using_tinytest.Rnw:251-252 (eval = FALSE)
 ###################################################
 ## options(tt.pr.passes=TRUE)
 
 
 ###################################################
-### code chunk number 11: using_tinytest.Rnw:257-258 (eval = FALSE)
+### code chunk number 11: using_tinytest.Rnw:258-259 (eval = FALSE)
 ###################################################
 ## run_test_dir("/path/to/your/test/directory")
 
 
 ###################################################
-### code chunk number 12: using_tinytest.Rnw:265-267
+### code chunk number 12: using_tinytest.Rnw:266-268
 ###################################################
 out <- run_test_dir(system.file("tinytest", package="tinytest")
        , verbose=0)
 
 
 ###################################################
-### code chunk number 13: using_tinytest.Rnw:271-272
+### code chunk number 13: using_tinytest.Rnw:272-273
 ###################################################
 head(as.data.frame(out), 3)
 
 
 ###################################################
-### code chunk number 14: using_tinytest.Rnw:278-279
+### code chunk number 14: using_tinytest.Rnw:279-280
 ###################################################
 summary(out)
 
 
 ###################################################
-### code chunk number 15: using_tinytest.Rnw:289-292 (eval = FALSE)
+### code chunk number 15: using_tinytest.Rnw:290-293 (eval = FALSE)
 ###################################################
 ## if ( expect_equal(1 + 1, 2) ){
 ##     expect_true( 2 > 0)
@@ -106,7 +106,7 @@ summary(out)
 
 
 ###################################################
-### code chunk number 16: using_tinytest.Rnw:302-305
+### code chunk number 16: using_tinytest.Rnw:303-306
 ###################################################
 if ( ignore(expect_equal)(1+1, 2) ){
   expect_true(2>0)
@@ -114,7 +114,7 @@ if ( ignore(expect_equal)(1+1, 2) ){
 
 
 ###################################################
-### code chunk number 17: using_tinytest.Rnw:313-316
+### code chunk number 17: using_tinytest.Rnw:314-317
 ###################################################
 if ( Sys.info()[['sysname']] == "Windows"){
   exit_file("Cannot test this on Windows")
@@ -175,20 +175,27 @@ run_test_file("test_se.R", verbose=1)
 
 
 ###################################################
-### code chunk number 26: using_tinytest.Rnw:513-515 (eval = FALSE)
+### code chunk number 26: using_tinytest.Rnw:501-503 (eval = FALSE)
+###################################################
+## output = pkg:::some_internal_function(1)
+## expect_equal(output, 2)
+
+
+###################################################
+### code chunk number 27: using_tinytest.Rnw:553-555 (eval = FALSE)
 ###################################################
 ## dat <- read.csv("women.csv")
 ## expect_equal(dat, women)
 
 
 ###################################################
-### code chunk number 27: using_tinytest.Rnw:527-528
+### code chunk number 28: using_tinytest.Rnw:567-568
 ###################################################
 options(prompt="  ", continue="  ")
 
 
 ###################################################
-### code chunk number 28: using_tinytest.Rnw:530-535 (eval = FALSE)
+### code chunk number 29: using_tinytest.Rnw:570-575 (eval = FALSE)
 ###################################################
 ## # contents of pkgdir/tests/tinytest.R
 ## if ( requireNamespace("tinytest", quietly=TRUE) ){
@@ -198,50 +205,56 @@ options(prompt="  ", continue="  ")
 
 
 ###################################################
-### code chunk number 29: using_tinytest.Rnw:540-541
+### code chunk number 30: using_tinytest.Rnw:580-581
 ###################################################
 home <- identical( Sys.getenv("HONEYIMHOME"), "TRUE" )
 
 
 ###################################################
-### code chunk number 30: using_tinytest.Rnw:545-546 (eval = FALSE)
+### code chunk number 31: using_tinytest.Rnw:585-586 (eval = FALSE)
 ###################################################
 ## home <- length(unclass(packageVersion("PKGNAME"))[[1]]) == 4
 
 
 ###################################################
-### code chunk number 31: using_tinytest.Rnw:550-551
+### code chunk number 32: using_tinytest.Rnw:590-591
 ###################################################
 options(prompt="R> ", continue="   ")
 
 
 ###################################################
-### code chunk number 32: using_tinytest.Rnw:558-560
+### code chunk number 33: using_tinytest.Rnw:598-600
 ###################################################
 run_test_file("test_hehe.R", verbose=0)
 run_test_file("test_hehe.R", verbose=0, at_home=FALSE)
 
 
 ###################################################
-### code chunk number 33: using_tinytest.Rnw:584-585 (eval = FALSE)
+### code chunk number 34: using_tinytest.Rnw:624-625 (eval = FALSE)
 ###################################################
 ## tinytest::test_package("hehe")
 
 
 ###################################################
-### code chunk number 34: using_tinytest.Rnw:629-630 (eval = FALSE)
+### code chunk number 35: using_tinytest.Rnw:657-658 (eval = FALSE)
+###################################################
+## test_package("tinytest", set_env = list(WA_BABALOOBA="BA_LA_BAMBOO"))
+
+
+###################################################
+### code chunk number 36: using_tinytest.Rnw:688-689 (eval = FALSE)
 ###################################################
 ## build_install_test("/path/to/your/package", ncpu=2)
 
 
 ###################################################
-### code chunk number 35: using_tinytest.Rnw:641-642 (eval = FALSE)
+### code chunk number 37: using_tinytest.Rnw:700-701 (eval = FALSE)
 ###################################################
 ## test_package("PACKAGENAME", ncpu=2)
 
 
 ###################################################
-### code chunk number 36: using_tinytest.Rnw:664-667 (eval = FALSE)
+### code chunk number 38: using_tinytest.Rnw:723-726 (eval = FALSE)
 ###################################################
 ## cl <- parallel::makeCluster(4, outfile="")
 ## parallel::clusterCall(cl, source, "R/myfunctions.R")
@@ -249,7 +262,7 @@ run_test_file("test_hehe.R", verbose=0, at_home=FALSE)
 
 
 ###################################################
-### code chunk number 37: using_tinytest.Rnw:674-677 (eval = FALSE)
+### code chunk number 39: using_tinytest.Rnw:733-736 (eval = FALSE)
 ###################################################
 ## parallel::clusterCall(cl, source, "R/myfunctions.R")
 ## test_all(cluster=cl)
@@ -257,7 +270,7 @@ run_test_file("test_hehe.R", verbose=0, at_home=FALSE)
 
 
 ###################################################
-### code chunk number 38: using_tinytest.Rnw:711-720
+### code chunk number 40: using_tinytest.Rnw:771-780
 ###################################################
 # exported, user-visible function
 inch2cm <- function(x){
@@ -271,7 +284,7 @@ conversion_factor <- function(unit){
 
 
 ###################################################
-### code chunk number 39: using_tinytest.Rnw:763-771
+### code chunk number 41: using_tinytest.Rnw:823-831
 ###################################################
 pound2kg <- function(x){
   stopifnot( is.numeric(x) )
@@ -284,7 +297,7 @@ pound2kg <- function(x){
 
 
 ###################################################
-### code chunk number 40: using_tinytest.Rnw:790-796 (eval = FALSE)
+### code chunk number 42: using_tinytest.Rnw:850-856 (eval = FALSE)
 ###################################################
 ##     expect_equal(pound2kg(1), 1/2.2046  )
 ##     # test for expected warning, store output
@@ -295,7 +308,7 @@ pound2kg <- function(x){
 
 
 ###################################################
-### code chunk number 41: using_tinytest.Rnw:841-847
+### code chunk number 43: using_tinytest.Rnw:901-907
 ###################################################
 bad_function <- function(file){
   oldwd <- getwd()
@@ -306,13 +319,13 @@ bad_function <- function(file){
 
 
 ###################################################
-### code chunk number 42: using_tinytest.Rnw:854-854
+### code chunk number 44: using_tinytest.Rnw:914-914
 ###################################################
 
 
 
 ###################################################
-### code chunk number 43: using_tinytest.Rnw:855-861
+### code chunk number 45: using_tinytest.Rnw:915-921
 ###################################################
 good_function <- function(file){
   oldwd <- getwd()
